@@ -51,19 +51,20 @@
 
   /* ---- bufer ---- */
   int mem_count(char [], char);
+  int mem_tcount(char [], char);
   int char_count(char [], char);
   int char_point(char *, char, int);
   int char_get(char *, char *, char, int);
   int clean_mem(char [], char, int);
   int set_mem(char [], char, int);
   int rm_crlf(char [], int);
-  int swap_mem(char [], char, char, int);
+  int swap_mem(char [], char, char);
   int self_memcpy(char *, char *, int);
   int self_strncat(char *, char *, int);
   int count_memcpy(char *, char *, int);
   char * count_memcpy2(char *, char *, int, int);
   int delim_count(char *, char, int, int *, int *);
-  int memcount_cpm(char *, char *, int, int);
+  int memcount_cpm(char *, char *, int, int, int);
   int ch_int(char *);
   int ch_int2(char *);
   int ch_int3(char *, char);
@@ -71,6 +72,7 @@
   int self_memcmp(char *, char *);
   int alversion(void);
   int mlexit(void);
+  int self_delim_get(char *, char *, char, int, int);
 
   /* --- heep bufer  ---- */
   char * safe_fpcat(FILE *, char *, int *, int);
@@ -86,6 +88,7 @@
   char * safe_base64(char *);
   char * safe_base64inheader(char *, char *);
   char * mime_ujtoj(char *);
+  char * null_free(char *);
 
   /* --- socket --- */
   int socket_reads(int, char * , int, int);
@@ -103,6 +106,7 @@
   int base64(char *, int, char *);
   char * base64_kai(char *);
   int ujtoj(unsigned char *, unsigned char *);
+  int randdata(int, int);
 
   /* --- time --- */
   char * char_wday(int);
@@ -115,12 +119,17 @@
   int month_last(int, int);
   int month_minus(int);
   char * time_getr(char *);
+  char * message_id(char * backdata, char * name, char * domain);
 
   /* --- socket --- */
   int socket_connect(struct sockaddr_in *, int, char [], int *);
   int socket_bind(struct sockaddr_in *, int, char *, int *);
   int socket_accept(struct sockaddr_in *, int *, int *);
 
+  /* --- thread --- */
+  #include<pthread.h>
+  int safe_pthread_mutex_lock(pthread_mutex_t *);
+
 #endif
 
 
