@@ -7,7 +7,7 @@
 
 
 /* --------------- MEMCOUNT_CPM ---------------- */
-int memcount_cpm(char * back, char * data, int sta, int sto)
+int memcount_cpm(char * back, char * data, int sta, int sto, int len)
 {
 int max, count, count1;
 max = (int)strlen(data);
@@ -20,6 +20,9 @@ if(max < 1 || sto < sta){
 for(count = sta; count <= sto && count < max; count++){
    back[count1] = data[count];
    count1++;
+   if(count1 > len){
+      break;
+      }
    }
 
 back[count1] = (char)0x00;
