@@ -19,11 +19,12 @@ FILE * fp;
 va_list args;
 long int len;
 
-if(data != NULL){
-   free(data);
-   data = NULL;
+if(data == NULL){
    data = (char *)calloc(BUF_LEN, sizeof(char));
    }
+else{
+   data = null_free(data);
+   }
 
 va_start(args, fmt);
 if((fp = fopen("/dev/null", "w+"))!=NULL){
