@@ -15,12 +15,24 @@ char * taro = (char *)calloc(12, sizeof(char));
 char * hana = (char *)calloc(12, sizeof(char));
 char * sachi = (char *)calloc(12, sizeof(char));
 
+char tt[1024];
+char * ttt = tt;
+char yy[1024];
+char * yyy = yy;
+memset(ttt, 0x00, 1024);
+memset(yyy, 0x00, 1024);
+
 ret = 0;
 sta = 0;
 sto = 0;
 
+
 alversion();
 
+self_memcpy(ttt, "12,34,56,78,90", 1024);
+self_delim_get(ttt, yyy, ',', 3, 1024);
+printf("ttt = %s, yyy = %s\n", ttt, yyy);
+
 taro = safe_memcpy(taro, "abcdef", 256);
 printf("SAFE_MEMCPY DATA =%s\n", taro);
 taro = safe_strncat(taro, "12345", 256);
@@ -54,7 +66,7 @@ ret = delim_count(taro, '-', 1, &sta, &sto);
 printf("DELIM_COUNT DATA= %s RET=%d STA= %d STO= %d\n", taro, ret, sta, sto);
 ret = mem_count(taro, '-');
 printf("MEM_COUNT DATA= %s RET=%d\n", taro, ret);
-ret = memcount_cpm(taro, "12345", 1, 3);
+ret = memcount_cpm(taro, "12345", 1, 3, 4);
 printf("MEMCOUNT_CPM DATA= %s RET=%d\n", taro, ret);
 taro = safe_memcpy(taro, "abcdef\r\n", 256);
 ret = rm_crlf(taro, (int)strlen(taro));
@@ -62,17 +74,19 @@ printf("RM_CRLF DATA= %s RET=%d\n", taro, ret);
 ret = set_mem(taro, 'd', (int)strlen(taro));
 printf("SET_MEM DATA= %s RET=%d\n", taro, ret);
 taro = safe_memcpy(taro, "02020", 256);
-ret = swap_mem(taro, '2', '1', strlen(taro));
+ret = swap_mem(taro, '2', '1');
 printf("SWAP_MEM DATA= %s RET=%d\n", taro, ret);
 ret = unlinkdir("/home/masashi/dirtest/");
 printf("UNLINKDIR PATH= %s RET=%d\n", "/home/masashi/dirtest/", ret);
 printf("char_wday(1) = %s\n", char_wday(1));
 printf("char_mon(1) = %s\n", char_wday(1));
-printf("utime_getr(0, 'y') = %d\n", utime_getr(0, 'y'));
-printf("utime_getr(0, 'm') = %d\n", utime_getr(0, 'm'));
-printf("utime_getr(0, 'd') = %d\n", utime_getr(0, 'd'));
+printf("utime_getr(, 'y') = %d\n", utime_getr(time(NULL), 'y'));
+printf("utime_getr(, 'm') = %d\n", utime_getr(time(NULL), 'm'));
+printf("utime_getr(, 'd') = %d\n", utime_getr(time(NULL), 'd'));
 printf("cutime_getr('y') = %d\n", ctime_getr('y'));
 printf("cutime_getr('m') = %d\n", ctime_getr('m'));
+taro = message_id(taro, "test", "ms-n.com");
+printf("Message_id(%s)\n", taro);
 
 taro = safe_memcpy(taro, "jjjjjjjjjjjjj", 1000);
 taro = safe_ujtoj(taro);
@@ -82,6 +96,12 @@ taro = safe_memcpy(taro, "@1234567890@", 1000);
 taro = safe_ujtoj(taro);
 taro = safe_memcpy(taro, "դդ줳줳ϤϤϤϤϤʤʤʤʤ", 1000);
 printf("mime_ujtoj(): <%s>\n", mime_ujtoj(taro));
+printf("randdata(): <%d>\n", randdata(0,25));
+printf("randdata(): <%d>\n", randdata(0,25));
+printf("randdata(): <%d>\n", randdata(0,25));
+printf("randdata(): <%d>\n", randdata(0,25));
+printf("randdata(): <%d>\n", randdata(0,25));
+printf("randdata(): <%d>\n", randdata(0,25));
 
 return 0;
 }
