@@ -64,6 +64,7 @@ $STAT = enco($_GET["STAT"]);
 $STARTTIME = enco($_GET["STARTTIME"]);
 $STOPSETTIME = enco($_GET["STOPSETTIME"]);
 $FREE1 = enco($_GET["FREE1"]);
+$FREE2 = enco($_GET["FREE2"]);
 $UNO = enco($_GET["UNO"]);
 
 
@@ -100,6 +101,7 @@ if(0 != strlen($BNAME)){
             $MAILTO = enco_rtrim(db_fetch_Result($result, $s, mailto));
             $MAILCC = enco_rtrim(db_fetch_Result($result, $s, mailcc));
             $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
+            $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
             $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
 
@@ -141,6 +143,9 @@ if(0 == strlen($STOPSETTIME)){
 if(0 == strlen($FREE1)){
    $FREE1 = "block infolmation";
    }
+if(0 == strlen($FREE2)){
+   $FREE2 = "mail priority";
+   }
 
 
 // ƻ륯饤ȥꥹȤκ
@@ -553,6 +558,21 @@ echo "<INPUT type='text' NAME=FREE1 size='100' value='$FREE1'>";
 echo "</td></tr>";
 
 
+echo "<tr bgcolor='#D9DBED'><td>";
+echo "顼᡼Υץ饤ƥ";
+echo "</td><td>";
+echo "<select size=1 name=FREE2>";
+echo "<option value=$FREE2 selected>$FREE2";
+echo "<option value=1>1";
+echo "<option value=2>2";
+echo "<option value=3>3";
+echo "<option value=4>4";
+echo "<option value=5>5";
+echo "</select>";
+echo "</td></tr>";
+
+
+
 echo "<tr><td>";
 echo "᡼ˡ";
 echo "</td><td>";
