@@ -365,10 +365,11 @@ if($num > 0){
       echo "<td $kcal1><font size=1>*</font></td>";
       echo "<td $kcal1><font size=1>ƻ֥å̾</font></td>";
       echo "<td $kcal1><font size=1>ֹ</font></td>";
+      echo "<td $kcal1><font size=1></font></td>";
       echo "</tr>";
 
       echo "<tr>";
-      echo "<td $kcal2><font size=1>*</font></td>";
+      echo "<td $kcal2><font size=1>TEST</font></td>";
       echo "<td $kcal2><font size=1>Խ</font></td>";
       echo "<td $kcal2><font size=1>ʣ</font></td>";
       echo "<td $kcal2><font size=1>*</font></td>";
@@ -384,6 +385,7 @@ if($num > 0){
       echo "<td $kcal2><font size=1>*</font></td>";
       echo "<td $kcal2><font size=1>BLOCKԽ</font></td>";
       echo "<td $kcal2><font size=1></font></td>";
+      echo "<td $kcal2><font size=1>*</font></td>";
       echo "</tr>";
       }
 
@@ -465,9 +467,12 @@ if($num > 0){
 
          }
       else{
+
+         $kazu = $s + 1;
+
          echo "<tr>"; 
 
-         echo "<td $cpcol>$COME</td>";
+         echo "<td $cpcol><a target=check href=$monitorcheck?UNO=$UNO&STATUS+UPDATE>$COME</a></td>";
          echo "<td $pcol><a target=edit href=$monitoredit?UNO=$UNO&STATUS=UPDATE>$CNAME</a></td>";
          echo "<td $ncol1><a target=edit href=$monitoredit?UNO=$UNO>$MONITOR</a></td>";
          echo "<td $ncol2>$SIGN</td>";
@@ -483,6 +488,7 @@ if($num > 0){
          echo "<td $ncol2>$FREE3</td>";
          echo "<td $ncol1><a target=edit href='./block.php?BNAME=$FREE4'>$FREE4</a></td>";
          echo "<td $ncol2><a target=edit href=$menucnew?BNAME=$FREE4>$UNO</a></td>";
+         echo "<td $ncol1>$kazu</td>";
 
          echo "</tr>";
          }
@@ -490,7 +496,7 @@ if($num > 0){
       $s++;
       }
 
-
+   $kazu = 0;
 
    if(0 != strcmp("on", $csv_ch)){
 
@@ -557,6 +563,7 @@ if($num > 0){
 
 
       echo "<td $ncol2>$dekinai</td>";
+      echo "<td $ncol1>$dekinai</td>";
 
       echo "</tr>";
 
