@@ -320,6 +320,7 @@ elseif($step1 > 0 && 0 == strcmp($MONITOR, "PORT") && $step2 <= 0){
    print("<option value=UDP>UDPݡȥå");
    print("<option value=TCP>TCPݡȥå");
    print("<option value=URL>URLơ");
+   print("<option value=SSL>SSLURLơ");
    print("<option value=SMTP>SMTPơ");
    print("<option value=SNTP>NTPФȤλֺǧ");
    print("<option value=HOST>DNS̾ǧ");
@@ -364,7 +365,17 @@ elseif($step1 > 0 && $step2 > 0 && $step3 <= 0){
    $count = 4;
    if(0 == strcmp($PROTO, "URL")){
       print("<tr><td>");
-      print("STEP3: ƻURL");
+      print("STEP3: ƻURL(http://Ϥʤ)");
+      print("</td></tr>");
+      print("<tr><td>");
+      print("<INPUT type='text' NAME=CIP value='$CIP'>");
+      print("<br>");
+      print("<a href='./monitor_manu.php?QUE_DATA=CIP&USER_NAME=$youname' target='top'>ιܤΥޥ˥奢</a><br>");
+      print("</td></tr>");
+      }
+   elseif(0 == strcmp($PROTO, "SSL")){
+      print("<tr><td>");
+      print("STEP3: ƻURL(SSL https:// Ϥʤ)");
       print("</td></tr>");
       print("<tr><td>");
       print("<INPUT type='text' NAME=CIP value='$CIP'>");
