@@ -35,7 +35,8 @@ interval = (gd.bf.life_int + gd.bf.life_los + INT_PLUS);
 
 intr = safe_sprintf(intr, BUF_MAX, "%s :: COM: ALGET DATA: %s\n", gd.bf.c_name, senddata);
 
-pthread_mutex_lock(&fd_mutex);      // socket mutex 開始
+//pthread_mutex_lock(&fd_mutex);      // socket mutex 開始
+safe_pthread_mutex_lock(&fd_mutex);      // socket mutex 開始
 
 if((stat = socket_send(gd.ip.sk, intr, interval)) > 0){   // ALGET の送信
    rec = alget_read(bat_filename, rec, gd.ip.sk, interval, &stat, (char)0x05, FILE_LEN, 0);
@@ -74,6 +75,7 @@ if(0 == self_memcmp(senddata, "COMAND") && 0 == memcmp(rec, "400", 3)){
       }
    }
 
+
 // 送信コマンドが"CRONFILE"であり、ステータスが400の場合、受け取ったファイルを/cron 以下に展開
 if(0 == self_memcmp(senddata, "CRONFILE") && 0 == memcmp(rec, "400", 3) && gd.cron_onoff == 1){
 
@@ -102,8 +104,9 @@ if(0 == self_memcmp(senddata, "CRONFILE") && 0 == memcmp(rec, "400", 3) && gd.cr
    }
 
 
-
+// もしファイルがない場合は手持ちのファイルをサーバにあげなおします。
 if(0 == (memcmp(rec, "500 NG", 6)) && stat != -1){
+
    fprintf(stderr,"get_alget(): server side comand or list file not open.\n");
 
    if(0 == (memcmp(senddata, "COMAND", 6))){
@@ -115,11 +118,11 @@ if(0 == (memcmp(rec, "500 NG", 6)) && stat != -1){
         "%s :: COM: AUPL DATA: PORT\n", gd.bf.c_name);
       }
 
-
    if((fp = fopen(bat_filename, "r"))!=NULL){
       fd = fileno(fp);
 
-      pthread_mutex_lock(&fd_mutex);
+//    pthread_mutex_lock(&fd_mutex);
+      safe_pthread_mutex_lock(&fd_mutex);
 
       if((stat = socket_send(gd.ip.sk, intr, interval)) > 0){
          rec = select_fdcat(gd.ip.sk, rec, &stat, BUF_MAX, interval); 
