@@ -17,6 +17,7 @@
 extern global_data_t gd;
 
 extern pthread_mutex_t fd_mutex;
+extern pthread_mutex_t break_mutex;
 extern char * sitarpid;
 
 
@@ -27,17 +28,18 @@ int get_statfile(char * senddata)
 FILE * fp;
 int pid, stat, interval;
 
-char * rec = (char *)calloc(IP_LEN, sizeof(char));
-char * recs = (char *)calloc(IP_LEN, sizeof(char));
-char * recdata = (char *)calloc(IP_LEN, sizeof(char));
-char * intr = (char *)calloc(IP_LEN, sizeof(char));
+char * rec = (char *)calloc(BUF_LEN, sizeof(char));
+char * recs = (char *)calloc(BUF_LEN, sizeof(char));
+char * recdata = (char *)calloc(BUF_LEN, sizeof(char));
+char * intr = (char *)calloc(BUF_LEN, sizeof(char));
 
 interval = (gd.bf.life_int + gd.bf.life_los + INT_PLUS);
 
 // intr = safe_sprintf(intr, BUF_MAX,"%s :: COM: UNDIF DATA: %s\n", gd.bf.c_name, senddata);
 intr = safe_sprintf(intr, BUF_MAX,"%s :: COM: SLGET DATA: %s\n", gd.bf.c_name, senddata);
 
-pthread_mutex_lock(&fd_mutex);
+//pthread_mutex_lock(&fd_mutex);
+safe_pthread_mutex_lock(&fd_mutex);
 if((stat = socket_send(gd.ip.sk, intr, interval)) > 0){
    rec = select_fdcat(gd.ip.sk, rec, &stat, BUF_MAX, interval);
    }
@@ -46,7 +48,8 @@ if(stat < 0){
    }
 pthread_mutex_unlock(&fd_mutex);
 
-swap_mem(rec, (char)0x05, (char)0x00, strlen(rec));
+// swap_mem(rec, (char)0x05, (char)0x00);
+swap_mem(rec, (char)0x05, ' ');
 
 #ifdef STATFILE_DEBUG
 printf("STATFILE: get_statfile(): %s\n", rec);
@@ -120,6 +123,8 @@ if(0 != (memcmp(rec, "500 NG", 6))){
          }
       }
 
+// pthread_mutex_lock(&break_mutex);
+   safe_pthread_mutex_lock(&break_mutex);
    if(0 == (memcmp("STOP", rec, 4))){
       #ifdef STATFILE_DEBUG
       printf("STATFILE: get_statfile(): STAT %s\n", rec);
@@ -153,6 +158,8 @@ if(0 != (memcmp(rec, "500 NG", 6))){
       gd.bf.stop_count = 1;
       return stat;
       }
+   pthread_mutex_unlock(&break_mutex);
+
    }
 
 else {
@@ -162,7 +169,8 @@ else {
      "%s :: COM: UP DATA: STAT:%s\n", gd.bf.c_name, "START");
 
    if(1 < (int)strlen(rec)){
-      pthread_mutex_lock(&fd_mutex);
+//    pthread_mutex_lock(&fd_mutex);
+      safe_pthread_mutex_lock(&fd_mutex);
       if((stat = socket_send(gd.ip.sk, intr, interval)) > 0){
          recdata = select_fdcat(gd.ip.sk, recdata, &stat, BUF_MAX, interval); 
          }
@@ -172,9 +180,7 @@ else {
       pthread_mutex_unlock(&fd_mutex);
       }
 
-   #ifdef STATFILE_DEBUG
-   printf("get_statfile(): %s\n", recdata);
-   #endif
+   fprintf(stderr,"get_statfile(): %s\n", recdata);
    }
 
 #ifdef FREE_BUG
@@ -185,7 +191,11 @@ free(recs);
 free(recdata);
 free(intr);
 
+//pthread_mutex_lock(&break_mutex);
+safe_pthread_mutex_lock(&break_mutex);
 gd.bf.stop_count = 1;
+pthread_mutex_unlock(&break_mutex);
+
 return stat;
 } 
 
