@@ -48,6 +48,18 @@ printf("------- %s for net-snmp -------\n", CL_VAR);
 printf("------- %s -------\n", CL_VAR);
 #endif
 
+printf("MAX THREAD              = %d(default)\n", B_LEN);
+printf("MAX process in thread   = %d(default)\n", B_MAX);
+printf("MAX Simultaneous thread = %d(default)\n", L_LEN);
+
+
+#ifdef KEEP_MALLOC
+printf("Large-scale operation use\n");
+#else
+printf("Small-scale operation use\n");
+#endif
+
+printf("Options\n");
 printf("     -c /*/** config file path\n");
 printf("\n");
 exit(1);
