@@ -716,13 +716,16 @@ if(mutexid == 0){
          pd->sb.ch_info = safe_sprintf(pd->sb.ch_info ,BUF_MAX,
            "%s :: COM: ERR DATA: %s\n", gd.bf.c_name, pd->sb.scan_all);
 
-//       pthread_mutex_lock(&fd_mutex);
          safe_pthread_mutex_lock(&fd_mutex);
          if((stat = socket_send(gd.ip.sk, pd->sb.ch_info, interval)) > 0){
             pd->sb.swap = select_fdcat(gd.ip.sk, pd->sb.swap, &stat, BUF_MAX, interval);
+            if(stat <= 0){
+               fprintf(stderr,"scan_block(1): exit!! stat=<%d> not recv data\n", stat);
+               safe_exit("scan_block(1):  socket err exit send data\n");
+               }
             }
-         if(stat < 0){
-            printf("scan_block(1): exit!! send data = <%s>\n",  pd->sb.ch_info);
+         else{
+            fprintf(stderr,"scan_block(1): exit!! stat=<%d> send data = <%s>\n", stat, pd->sb.ch_info);
             safe_exit("scan_block(1):  socket err exit send data\n");
             }
          pthread_mutex_unlock(&fd_mutex);
@@ -778,17 +781,23 @@ if(mutexid == 0){
             pd->sb.ch_info = safe_sprintf(pd->sb.ch_info ,BUF_MAX,
               "%s :: COM: ERR DATA: %s\n", gd.bf.c_name, pd->sb.scan_all);
 
-//          pthread_mutex_lock(&fd_mutex);
+
             safe_pthread_mutex_lock(&fd_mutex);
             if((stat = socket_send(gd.ip.sk, pd->sb.ch_info, interval)) > 0){
                pd->sb.swap = select_fdcat(gd.ip.sk, pd->sb.swap, &stat, BUF_MAX, interval);
+               if(stat <= 0){
+                  fprintf(stderr,"scan_block(2): exit!! stat=<%d> not recv data\n", stat);
+                  safe_exit("scan_block(2):  socket err exit send data\n");
+                  }
                }
-            if(stat < 0){
-               printf("scan_block(2): exit!! send data = <%s>\n",  pd->sb.ch_info);
-               safe_exit("scan_block(2):  socket err exit \n");
+            else{
+               fprintf(stderr,"scan_block(2): exit!! stat=<%d> send data = <%s>\n", stat, pd->sb.ch_info);
+               safe_exit("scan_block(2):  socket err exit send data\n");
                }
             pthread_mutex_unlock(&fd_mutex);
 
+
+
 //          pd->sb.ch_info = safe_memcpy(pd->sb.ch_info, "\0", BUF_MAX);
 //          pd->sb.swap = safe_memcpy(pd->sb.swap, "\0", BUF_MAX);
             pd->sb.ch_info = null_free(pd->sb.ch_info);
