@@ -1,5 +1,4 @@
 
-
 #ifdef NET_SNMP_IN
 
 
@@ -26,10 +25,6 @@ int cal4(int, int, char);
 int ch_en(char);
 
 
-
-/* 戃Tり倁AぃbゃBッDッV文僅列 */
-/* 1) OID 2) 戃Tり倁A、マッックされたポめAッEゃ\ッV 3) int * ゃPテーゃ\ゃP、int * 戃Tり倁A甃B敃G敁|、整敁|ぃ堃G合は結果ぃ敁|字 */
-/* -------- OID CALC -------- */
 char * cal_oid(char * oid, char * backdata, int * stat, int * ret, char * port, char * host, int *chk, int timeout)
 { 
 char * da;
@@ -240,7 +235,7 @@ else{
    plai = 3;
    }
 
-// 閃Z倁AがNOTぃ堃G合、戻り倁Aぃb緃B集なしで元BぃそのぃZぃZ返す
+// 閾値がNOTの場合、戻り値は編集しないでそのまま返す
 if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
    backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_23);
@@ -255,8 +250,7 @@ if(0 == memcmp(pd->ch_prot, "NOT", 3) || 0 == memcmp(pd->ch_port, "NON", 3)){
       }
    }
 
-
-// 閃Z倁AがLOGぃ堃G合、戻りを敁|字に戃Tさず、そぃぃZぃZ返す
+// 閾値がLOGの場合、戻りを数字に戻さずそのまま返す
 else if(0 == memcmp(pd->ch_prot, "LOG", 3) || 0 == memcmp(pd->ch_port, "log", 3)){
 
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 0, &chk, pd->timeout);
@@ -271,8 +265,7 @@ else if(0 == memcmp(pd->ch_prot, "LOG", 3) || 0 == memcmp(pd->ch_port, "log", 3)
       }
    }
 
-
-// 閃Z倁Aぃ先頃が−ぃ堃G
+// 閾値の先頭がマイナスの場合
 else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
 
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
@@ -325,10 +318,9 @@ else if(pd->ch_prot[0] == '-' && 1 < (int)strlen(pd->ch_prot)){
       } 
    }
 
-
-// 閃Z倁Aぃ先頃がVの堃G
+// 閾値の先頭が＋の場合
 else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
-   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX); // buf +1 ぃb一文僅VVVvばしです
+   chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    if(-1 != ch_int(chhi)){
       if((hi = strtol(chhi, (char **)NULL, 10)) >= 0){
          pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
@@ -378,8 +370,7 @@ else if(pd->ch_prot[0] == '+' && 1 < (int)strlen(pd->ch_prot)){
       } 
    }
 
-
-// 閃Z倁Aぃ先頃がVの堃G
+// 閾値の先頭が！の場合
 else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
@@ -418,7 +409,7 @@ else if(pd->ch_prot[0] == '!' && 1 < (int)strlen(pd->ch_prot)){
    }
 
 
-// 閃Z倁Aぃ先頃がVの堃G
+// 閾値の先頭が＝の場合
 else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
    chhi = safe_memcpy(chhi, pd->ch_prot + 1, BUF_MAX);
    pd->ch_info = snmp_test(pd->ch_info, pd->ch_port, pd->ch_host, pd->ch_com, &ret, 1, &chk, pd->timeout);
@@ -457,7 +448,7 @@ else if(pd->ch_prot[0] == '=' && 1 < (int)strlen(pd->ch_prot)){
    }
 
 
-// それ仁E外の堃G合もNOTぃB同じ凃理 但し、間違いを情v
+// それ以外の場合もNOTと同じ処理、但し間違いを正す。
 else {
    pd->ch_info = cal_oid(pd->ch_com, pd->ch_info, &ret, &inret, pd->ch_port, pd->ch_host, &chk, pd->timeout);
    backdata = safe_sprintf(backdata, BUF_MAX,"(%s) %s\n", pd->ch_info, SNMP_13);
@@ -474,8 +465,7 @@ else {
    }
 
 
-
-// テストとッめ|チuッVドの凃
+// TEXTとLOGモードの処理
 if(0 == self_memcmp(pd->ch_plai, "4")){
    #ifdef SNMP_DEBUG
    printf("SNMP_DEBUG: scan_snmp(): snmp chack plai=%s check_stat=%d\n", pd->ch_plai, pd->check_stat);
@@ -512,8 +502,7 @@ else if(0 == self_memcmp(pd->ch_plai, "13")){
 
 
 
-// check_statぃ訃定 歁vか逆かぃ@反Tuする
-// 盁v視の歁v逆の刁A斃 check_stat == 1 ぃbゃBッDッV 0ぃb歁v布N
+// CHECK STAT設定　正か逆かで反転する。監視の正逆の判断 check_stat == 1はエラー、0は正常です。
 if(ret < 0){
    if(pd->ch_stat[0] == '0'){
       pd->check_stat = 1;
@@ -534,7 +523,6 @@ if(ret >= 0){
    }
 
 
-/* */
 free(chhi);
 free(chho);
 free(backdata);
@@ -550,6 +538,3 @@ return(ret);
 #endif
 
 
-
-
-
