@@ -23,6 +23,8 @@ int set_data(void)
      gd.fi.bat_filename_2 = safe_memcpy(gd.fi.bat_filename_2, "/tmp/sitar.bat_2", BUF_SLEN);
      gd.fi.bat2_filename = safe_memcpy(gd.fi.bat2_filename, "/tmp/sitar.list", BUF_SLEN);
      gd.fi.bat2_filename_2 = safe_memcpy(gd.fi.bat2_filename_2, "/tmp/sitar.list_2", BUF_SLEN);
+     gd.fi.midump_filename = safe_memcpy(gd.fi.midump_filename, "/usr/local/zither/tmp/midump.txt", BUF_SLEN);
+     gd.fi.midump_filename_2 = safe_memcpy(gd.fi.midump_filename_2, "/usr/local/zither/tmp/midump_2.txt", BUF_SLEN);
      gd.fi.command_path = safe_memcpy(gd.fi.command_path, "/usr/local/zither/sample_bin", BUF_SLEN);
      gd.fi.cron_path = safe_memcpy(gd.fi.cron_path, "/usr/local/zither/cron", BUF_SLEN);
      gd.fi.update_com = safe_memcpy(gd.fi.update_com, "/usr/local/zither/bin/get_sitar.sh", BUF_SLEN);
@@ -40,6 +42,10 @@ int set_data(void)
      gd.smtp.ch_MailCc = safe_memcpy(gd.smtp.ch_MailCc, "NOT", BUF_LEN);
      gd.td.tcount = B_LEN;    // thread count max
      gd.td.tbufmax = B_MAX;   // thread buf count max
+     gd.td.midcount = B_MID;   // mid max
+     gd.td.midint = MID_INT;   // mid auto dump interval
+     gd.td.thread_max = L_LEN; // thread_max
+     gd.td.thread_count = 0;
 
      if(gd.cron_onoff < 0){ gd.cron_onoff = 0; }
 
