@@ -2,7 +2,7 @@
 #include<stdlib.h>
 
 #include"zither_lint.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 
 extern global_data_t gd;
