@@ -20,13 +20,15 @@ extern global_data_t gd;
 
 int errdata_tok(private_data_t * pd, unsigned char * ip)
 {
-int maxlen, maxdel, ret, middleno;
+int maxlen, maxdel, ret, middleno, splen, spmax;
 char * swap = (char *)calloc(IP_LEN, sizeof(char));
 char * swapdata = (char *)calloc(IP_LEN, sizeof(char));
 char * swapsubject = (char *)calloc(IP_LEN, sizeof(char));
 char * tmp;
 
 middleno = 0;
+spmax = 0;
+splen = 0;
 
 swap = safe_memcpy(swap, pd->rec.data, BUF_MAX);
 maxlen = strlen(swap);
@@ -62,12 +64,12 @@ if(0 < maxdel && 13 <= maxlen){
       else{
          pd->rec.data = safe_memcpy(pd->rec.data, swapdata, BUF_MAX);
          }
-
       }
    else{
-      pd->rec.data = safe_sprintf(pd->rec.data, BUF_MAX, "Broken data. %s\n\n", swapdata);
+      pd->rec.data = safe_sprintf(pd->rec.data, BUF_MAX, "Broken data. <1>: %s\n\n", swapdata);
       }
 
+
    for(;0 < maxdel; maxdel--){
       swapdata = safe_memcpy(swapdata, strtok_r(NULL, ";", &tmp), BUF_MAX);
       if(20 == char_count(swapdata,',') && 20 <= strlen(swapdata)){ 
@@ -78,25 +80,31 @@ if(0 < maxdel && 13 <= maxlen){
          pthread_mutex_unlock(&err_mutex);
          #endif
          swapdata = mail_form(swapdata, pd, ip, &middleno);
-         pd->rec.data = safe_strncat(pd->rec.data, swapdata, BUF_MAX);
+
+         if((splen = (int)strlen(swapdata)) > 0 ){
+            pd->rec.data = safe_strncat(pd->rec.data, swapdata, BUF_MAX);
+            spmax = spmax + splen;
+            splen = 0;
+
+            }
          }
       else{
-         pd->rec.data = safe_sprintf(pd->rec.data, BUF_MAX, "Broken data. %s\n\n", swapdata);
+         pd->rec.data = safe_sprintf(pd->rec.data, BUF_MAX, "Broken data. <2>: %s\n\n", swapdata);
          }
       }
    }
 else{
-   pd->rec.data = safe_sprintf(pd->rec.data, BUF_MAX, "Broken data. %s\n\n", swap);
+   pd->rec.data = safe_sprintf(pd->rec.data, BUF_MAX, "Broken data. <3>: %s\n\n", swap);
    }
 
 // 特殊用途です。
 #ifdef SERVICES_MODE
-// pd->rec.minfo = safe_sprintf(pd->rec.minfo, BUF_MAX, "%s\n", CLIENT_BODY_10);
-pd->rec.minfo = safe_sprintf(pd->rec.minfo, BUF_MAX, "%s\n%s\nhttps://%s/custommer/%s",
-   CLIENT_BODY_10, CLIENT_BODY_13, gd.pg.pg_webserver, pd->rec.user_org);
+pd->rec.minfo = safe_sprintf(pd->rec.minfo, BUF_MAX, "%s\n%s\nhttps://%s/customer/errorlist.php",
+   CLIENT_BODY_10, CLIENT_BODY_13, gd.pg.pg_webserver);
 pd->rec.tinfo = safe_sprintf(pd->rec.tinfo, BUF_MAX, "E-mail of server watch service by %s\n", CL_VAR);
 #else
 
+
 // ブロック設定をURLから検索させるかの判断
 #ifdef URL_SEARCH
 pd->rec.minfo = safe_sprintf(pd->rec.minfo, BUF_MAX,
@@ -130,7 +138,8 @@ pd->rec.tinfo = safe_sprintf(pd->rec.tinfo, BUF_MAX,
 #endif
 
 
-if(2 <= strlen(pd->rec.data)){
+//if(2 <= strlen(pd->rec.data)){
+if(2 <= spmax){
 
    if(pd->mail.in_mailonoff == 1){
       //  subject を作ります
@@ -138,7 +147,7 @@ if(2 <= strlen(pd->rec.data)){
 
       // 本文を作ります
       swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.minfo, pd->rec.data, pd->rec.tinfo); 
-      swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+      swap_mem(swapdata, '\n', (char)0x01);
 
       mail_grsend(pd->mail.server,
                pd->mail.from,
@@ -147,7 +156,7 @@ if(2 <= strlen(pd->rec.data)){
                swapdata,
                swapsubject,    
                gd.on_bcc,
-               "2");
+               pd->mail.priority);
      }
   }
 
