@@ -8,6 +8,7 @@
 #include<string.h>
 #include<netinet/in.h>
 #include<arpa/inet.h>
+#include<errno.h>
 #include<pthread.h>
 
 #include"zither.h"
@@ -21,7 +22,7 @@ extern global_data_t gd;
 /*--------------- LIFE_LOGIC ------------------- */
 int life_logi(private_data_t * pd)
 {
-int ret;
+int ret, tret;
 int checktime, bstat, cstat, fstat, sstat, crfilestat, crliststat;
 
 checktime = 0;
@@ -32,6 +33,8 @@ sstat =0;
 crfilestat =0;
 crliststat =0;
 
+errno = 0;
+tret = 0;
 
 char * swap2 = (char *)calloc(IP_LEN, sizeof(char));
 char * swap3 = (char *)calloc(IP_LEN, sizeof(char));
@@ -48,7 +51,9 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
 
    if(pd->life.onoff == 1){
       // life thread 
-      pthread_create( &pd->life.life_t, NULL, (void *)life_thread, pd );
+      if((tret = pthread_create( &pd->life.life_t, NULL, (void *)life_thread, pd )) != 0 ){
+         fprintf(stderr,"life_logi.c life_logi(): pthread_create %d\n", tret);
+         }
       checktime = life_check(pd);
       #ifdef LIFE_DEBUG
       printf("LIFE_DEBUG: life_logi():  CHECK_TIME> %s >checktime=%d life_los=%d\n",
@@ -67,7 +72,7 @@ if(ustat == 0 && astat != 0 && cgstat != 0){
 
             // 本文をつくります
             swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, pd->life.swap1, CL_VAR);
-            swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+            swap_mem(swapdata, '\n', (char)0x01);
 
             mail_grsend(pd->mail.server,
                      pd->mail.from,
