@@ -50,7 +50,7 @@ char * free4 = (char *)calloc(2, sizeof(char));
 char * kanshi = (char *)calloc(2, sizeof(char));
 char * pri_data = (char *)calloc(2, sizeof(char));
 
-swap_mem(swap, '\'', ' ', (int)strlen(swap));
+swap_mem(swap, '\'', ' ');
 
 tool = delim_get(swap, tool, ',', &ret, 0);
 utime = delim_get(swap, utime, ',', &ret, 1);
@@ -85,6 +85,32 @@ if(0 == self_memcmp(tool, "SET")){
    printf("DEBUG: mail_form(): Geting SET free1=%s free2=%s free3=%s free4=%s\n", free1, free2, free3, free4);
    #endif
 
+
+   //  SET 個別でプライオリティーを設定する部分 char * にするのはちょっと、、、あとでなおす。
+   if(0 == self_memcmp(plai, "1")){
+      pd->mail.priority = safe_memcpy(pd->mail.priority, "1", BUF_LEN);
+      }
+   else if(0 == self_memcmp(plai, "2")){
+      pd->mail.priority = safe_memcpy(pd->mail.priority, "2", BUF_LEN);
+      }
+   else if(0 == self_memcmp(plai, "3")){
+      pd->mail.priority = safe_memcpy(pd->mail.priority, "3", BUF_LEN);
+      }
+   else if(0 == self_memcmp(plai, "4")){
+      pd->mail.priority = safe_memcpy(pd->mail.priority, "4", BUF_LEN);
+      }
+   else if(0 == self_memcmp(plai, "5")){
+      pd->mail.priority = safe_memcpy(pd->mail.priority, "5", BUF_LEN);
+      }
+   else {
+      pd->mail.priority = safe_memcpy(pd->mail.priority, "3", BUF_LEN);
+      }
+
+   #ifdef MAIL_DEBUG
+   printf("MAIL_DEBUG: mail_form(): SET MAIL PRIORITY = %s id = %s ---------\n", plai, pd->mail.priority);
+   #endif
+
+
    if(0 == self_memcmp(info, "MID2")){
       * middleno = 1;
       }
@@ -140,13 +166,13 @@ if(0 == self_memcmp(tool, "SET")){
       /* user side mail.rcptto set */
       pd->mail.rcptto_org = safe_memcpy(pd->mail.rcptto_org, free2, BUF_LEN);
       pd->mail.cc_org = safe_memcpy(pd->mail.cc_org, " ", BUF_LEN);
-      swap_mem( pd->mail.rcptto_org, '|', ',', (int)strlen(pd->mail.rcptto_org));
+      swap_mem( pd->mail.rcptto_org, '|', ',');
 
       /*  set Cc: */ 
       if(0 != self_memcmp(free3, "NOT") && 4 <= strlen(free3) && 2 <= char_point(free3, '@', 1)){
          /* user side mail.rcptto set */
          pd->mail.cc_org = safe_memcpy(pd->mail.cc_org, free3, BUF_LEN);
-         swap_mem( pd->mail.cc_org, '|', ',', (int)strlen(pd->mail.cc_org));
+         swap_mem( pd->mail.cc_org, '|', ',');
          }
 
       }
@@ -159,7 +185,7 @@ if(0 == self_memcmp(tool, "SET")){
 
    clean_mem(swap, (char)0x00, (int)strlen(swap));
    goto mail_form_end;
-   }
+   }   // SET 
 
 
 #ifdef POSTGRES_IN
@@ -199,7 +225,7 @@ swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d', '%s', '%s', '%s', '%s'
 printf("POSTGRES_DEBUG: mail_form(): PG_INDATA > %s\n", swap);
 #endif
 
-swap_mem(swap, (char)0x01, '\n', (int)strlen(swap));
+swap_mem(swap, (char)0x01, '\n');
 
 
 /* data insert */
@@ -246,7 +272,7 @@ swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%s','%s','%s
 printf("MYSQL_DEBUG: mail_form(): MYSQL_INDATA > %s\n", swap);
 #endif
 
-swap_mem(swap, (char)0x01, '\n', (int)strlen(swap));
+swap_mem(swap, (char)0x01, '\n');
 
 
 /* data insert */
@@ -256,10 +282,6 @@ pthread_mutex_unlock(&mysql_mutex);
 #endif
 
 
-// メールのプライオリティー設定
-
-
-
 
 
 // メールのプライオリティー設定
@@ -287,7 +309,7 @@ if(pri < 3){
 
    // 特殊用途です
    #ifdef SERVICES_MODE
-// kanshi = safe_sprintf(kanshi, BUF_MAX,"%shttps://%s/custommer/%s/monitor_edit.php?STATUS=UPDATE&UNO=%s",
+// kanshi = safe_sprintf(kanshi, BUF_MAX,"%shttps://%s/customer/%s/monitor_edit.php?STATUS=UPDATE&UNO=%s",
    kanshi = safe_memcpy(kanshi, "", BUF_MAX);
    #else
 
@@ -417,6 +439,28 @@ if(pri < 3){
            MAIL_NTP_19,
            info);
          }
+
+      else if(0 == self_memcmp(prot, "ICMP")){
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+           MAIL_ICMP_11,
+           kanshi,
+           MAIL_ICMP_12,
+           pri_data,
+           MAIL_ICMP_13,
+           prot,
+           MAIL_ICMP_14,
+           host,
+           MAIL_ICMP_15,
+           port,
+           MAIL_ICMP_16,
+           timeout,
+           MAIL_ICMP_17,
+           free1,
+           MAIL_ICMP_18,
+           data,
+           MAIL_ICMP_19,
+           info);
+         }
       else{
 //       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
          swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
@@ -530,6 +574,29 @@ if(pri < 3){
            MAIL_NTP_29,
            info);
          }
+
+      else if(0 == self_memcmp(prot, "ICMP")){
+         swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
+           MAIL_ICMP_21,
+           kanshi,
+           MAIL_ICMP_22,
+           pri_data,
+           MAIL_ICMP_23,
+           prot,
+           MAIL_ICMP_24,
+           host,
+           MAIL_ICMP_25,
+           port,
+           MAIL_ICMP_26,
+           timeout,
+           MAIL_ICMP_27,
+           free1,
+           MAIL_ICMP_28,
+           data,
+           MAIL_ICMP_29,
+           info);
+         }
+
       else{
 //       swap = safe_sprintf(swap, BUF_MAX, "%s\n%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
          swap = safe_sprintf(swap, BUF_MAX, "%s\n%s%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n%s%s\n\n",
