@@ -41,7 +41,7 @@ if(ustat == 0 || astat == 0 || cgstat == 0){
 
       // 本文をつくります
       swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, CLIENT_BODY_7, CL_VAR);
-      swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+      swap_mem(swapdata, '\n', (char)0x01);
 
       mail_grsend(pd->mail.server,
                pd->mail.from,
