@@ -11,6 +11,7 @@
 #include<string.h>
 #include<pthread.h>
 #include<time.h>
+#include<signal.h>
 #include<errno.h>
 
 #include"zither.h"
@@ -45,6 +46,12 @@ int tret;
 errno = 0;
 tret = 0;
 
+signal(SIGINT, signal_exit);
+signal(SIGKILL, signal_exit);
+signal(SIGQUIT, signal_exit);
+signal(SIGHUP, signal_exit);
+// signal(SIGTERM, signal_exit);  // BSDの為
+
 malloc_set();
 set_data();
 optin(argc, argv);
