@@ -146,6 +146,7 @@
         char * cronlist_filename;   /* active */
         } file;
      struct {
+        char * priority;
         char * server;              /* active */
         char * block;              /* active */
         char * from;                /* active */
@@ -178,7 +179,7 @@
   typedef struct global_data global_data_t;
 
   struct global_data {
-    pthread_t * pt;
+    pthread_t * pt;                    // thread 識別子
     char * db_select;                  // どっちのDBを使うのかの選択（でふぉはぽすぐれPGSQL）
     char * on_bcc;                     // 送信する全てのメールのコピーを送信するあどれす。
     int cron_onoff;                    // cron 機能を使う場合は1、使わない場合は0
